@@ -109,19 +109,9 @@ class AccountQuery(AccountFields, Query):
     Project
     """
 
-    def select_projects(self, first=100, last=None, after=None, before=None):
-        """Selects account projects.
-
-        :param first: Number of records to fetch from start
-        :type first: int
-        :param last: Number of records to fetch from end
-        :type last: int
-        :param after: Fetch after cursor
-        :type after: str
-        :param before: Fetch before cursor
-        :type before: str
-        """
-        projects = self.ds.Account.projects.args(first=first, last=last, after=after, before=before)
+    def select_projects(self):
+        """Selects account projects."""
+        projects = self.ds.Account.projects.args(**self.var_pagination)
         projects_nodes = self.ds.ProjectConnection.nodes.select(*ProjectFields.fields(self.ds))
         pagination = self.ds.ProjectConnection.pageInfo.select(*self.page_fields())
 
