@@ -55,7 +55,7 @@ class DeepCrawlConnection:
     def __repr__(self) -> str:
         return "DeepCrawlConnection instance"
 
-    def run_query(self, query):
+    def run_query(self, query, variables=None, var=None, **kwargs):
         """Runs a query.
 
         >>> conn = DeepCrawlConnection("user_key_id", "secret")
@@ -79,6 +79,46 @@ class DeepCrawlConnection:
                 'username': 'email@example.com'
             }
         }
+
+        >>> from gql.dsl import DSLVariableDefinitions
+        >>> from gql.dsl import DSLQuery
+        >>> var = DSLVariableDefinitions()
+        >>> query = conn.ds.Query.me.select(
+                conn.ds.User.accounts.args(first=var.first, after=var.after)
+                .select(
+                    conn.ds.AccountConnection.nodes.select(
+                        conn.ds.Account.id,
+                        conn.ds.Account.name,
+                    )
+                )
+                .select(
+                    conn.ds.AccountConnection.pageInfo.select(
+                        conn.ds.PageInfo.startCursor,
+                        conn.ds.PageInfo.endCursor,
+                        conn.ds.PageInfo.hasNextPage,
+                        conn.ds.PageInfo.hasPreviousPage,
+                    )
+                )
+            )
+        >>> conn.run_query(query, variables={"first": 1, "after": "MQ"}, var=var)
+        {
+            "me": {
+                "accounts": {
+                    "nodes": [
+                        {
+                            "id": "id",
+                            "name": "name"
+                        }
+                    ],
+                    "pageInfo": {
+                        "startCursor": "Mg",
+                        "endCursor": "Mg",
+                        "hasNextPage": false,
+                        "hasPreviousPage": true
+                    }
+                }
+            }
+        }
         # For more information about constructing queries with dsl
         # see https://gql.readthedocs.io/en/stable/advanced/dsl_module.html
 
@@ -110,18 +150,34 @@ class DeepCrawlConnection:
 
         :param query: query object
         :type query: str or Query
+        :param variables: variables to use in the query.
+            run_query(... {"first": 1, "after": "MQ"})
+        :type variables: dict or None
+        :param var: gql DSLVariableDefinitions instance to be used in the query.
+            Works tougether with variables
+        :type var: DSLVariableDefinitions
+        :param kwargs: variables to use in the query.
+            If variables is not used and the user prefers to send variables as function arguments
+            run_query(... first=1, after="MQ")
         """
         from deepcrawl_graphql.query import Query  # pylint: disable=import-outside-toplevel
 
         if isinstance(query, Query):
-            query = dsl_gql(DSLQuery(query.query))
+            _query = DSLQuery(query.query)
+            _query.variable_definitions = query.var
+            query = dsl_gql(_query)
         if isinstance(query, DSLField):
-            query = dsl_gql(DSLQuery(query))
+            if var:
+                _query = DSLQuery(query)
+                _query.variable_definitions = var
+                query = dsl_gql(_query)
+            else:
+                query = dsl_gql(DSLQuery(query))
         elif isinstance(query, DSLQuery):
             query = dsl_gql(query)
         elif isinstance(query, str):
             query = gql(query)
-        return self.client.execute(query)
+        return self.client.execute(query, variables or kwargs)
 
     @staticmethod
     def _get_token(user_key_id, secret) -> str:
