@@ -86,19 +86,9 @@ class CrawlQuery(CrawlFields, Query):
     Report
     """
 
-    def select_reports(self, first=100, last=None, after=None, before=None):
-        """Selects crawl reports.
-
-        :param first: Number of records to fetch from start
-        :type first: int
-        :param last: Number of records to fetch from end
-        :type last: int
-        :param after: Fetch after cursor
-        :type after: str
-        :param before: Fetch before cursor
-        :type before: str
-        """
-        reports = self.ds.Crawl.reports.args(first=first, last=last, after=after, before=before)
+    def select_reports(self):
+        """Selects crawl reports."""
+        reports = self.ds.Crawl.reports.args(**self.var_pagination)
         report_nodes = self.ds.ReportConnection.nodes.select(*ReportFields.fields(self.ds))
         pagination = self.ds.ReportConnection.pageInfo.select(*self.page_fields())
 
