@@ -36,19 +36,9 @@ class MeQuery(MeFields, Query):
         self.query.select(*self.fields(self.ds))
         return self
 
-    def select_accounts(self, first=100, last=None, after=None, before=None):
-        """Selects users accounts.
-
-        :param first: Number of records to fetch from start
-        :type first: int
-        :param last: Number of records to fetch from end
-        :type last: int
-        :param after: Fetch after cursor
-        :type after: str
-        :param before: Fetch before cursor
-        :type before: str
-        """
-        accounts = self.ds.User.accounts.args(first=first, last=last, after=after, before=before)
+    def select_accounts(self):
+        """Selects users accounts."""
+        accounts = self.ds.User.accounts.args(**self.var_pagination)
         account_nodes = self.ds.AccountConnection.nodes.select(*AccountFields.fields(self.ds))
         pagination = self.ds.AccountConnection.pageInfo.select(*self.page_fields())
 
