@@ -109,19 +109,9 @@ class ProjectQuery(ProjectFields, Query):
     Crawl
     """
 
-    def select_crawls(self, first=100, last=None, after=None, before=None):
-        """Selects project crawls.
-
-        :param first: Number of records to fetch from start
-        :type first: int
-        :param last: Number of records to fetch from end
-        :type last: int
-        :param after: Fetch after cursor
-        :type after: str
-        :param before: Fetch before cursor
-        :type before: str
-        """
-        crawls = self.ds.Project.crawls.args(first=first, last=last, after=after, before=before)
+    def select_crawls(self):
+        """Selects project crawls."""
+        crawls = self.ds.Project.crawls.args(**self.var_pagination)
         crawl_nodes = self.ds.CrawlConnection.nodes.select(*CrawlFields.fields(self.ds))
         pagination = self.ds.CrawlConnection.pageInfo.select(*self.page_fields())
 
