@@ -3,6 +3,8 @@ Query
 =====
 """
 
+from gql.dsl import DSLVariableDefinitions
+
 from deepcrawl_graphql.api import DeepCrawlConnection
 
 
@@ -12,6 +14,13 @@ class Query:
     def __init__(self, conn: DeepCrawlConnection) -> None:
         self.ds = conn.ds
         self.query = self.ds.Query
+        self.var = DSLVariableDefinitions()
+        self.var_pagination = {
+            "first": self.var.first.default(100),
+            "last": self.var.last,
+            "after": self.var.after,
+            "before": self.var.before,
+        }
 
     def page_fields(self):
         """Returns a tule of PageInfo fields."""
